@@ -54,7 +54,7 @@ def run_many_consumer_with_multi_process(consumer_init_params_list: List[dict],
     [Process(target=run_many_consumer_by_init_params, args=(consumer_init_params_list,)).start() for _ in range(process_num)]
 
 
-def task_deco(queue_name, *, function_timeout=0, threads_num=50,
+def task_deco(queue_name, *, function_timeout=0,
               concurrent_num=50, specify_concurrent_pool=None, specify_async_loop=None, concurrent_mode=1,
               max_retry_times=3, log_level=10, is_print_detail_exception=True, msg_schedule_time_intercal=0.0,
               qps: float = 0, msg_expire_senconds=0, is_using_distributed_frequency_control=False,
@@ -70,15 +70,16 @@ def task_deco(queue_name, *, function_timeout=0, threads_num=50,
     # 为了代码提示好，这里重复一次入参意义。被此装饰器装饰的函数f，函数f对象本身自动加了一些方法，例如f.push 、 f.consume等。
     :param queue_name: 队列名字。
     :param function_timeout : 超时秒数，函数运行超过这个时间，则自动杀死函数。为0是不限制。
-    :param threads_num:并发数量，协程或线程。由concurrent_mode决定并发种类。
-    :param concurrent_num:并发数量，这个覆盖threads_num。以后会废弃threads_num参数，因为表达的意思不太准确，不一定是线程模式并发。
+    # 如果设置了qps，并且cocurrent_num是默认的50，会自动开了500并发，由于是采用的智能线程池任务少时候不会真开那么多线程而且会自动缩小线程数量。具体看ThreadPoolExecutorShrinkAble的说明
+    # 由于有很好用的qps控制运行频率和智能扩大缩小的线程池，此框架建议不需要理会和设置并发数量只需要关心qps就行了，框架的并发是自适应并发数量，这一点很强很好用。
+    :param concurrent_num:并发数量
     :param specify_concurrent_pool:使用指定的线程池（协程池），可以多个消费者共使用一个线程池，不为None时候。threads_num失效
     :param specify_async_loop:指定的async的loop循环，设置并发模式为async才能起作用。
     :param concurrent_mode:并发模式，1线程 2gevent 3eventlet 4 asyncio
     :param max_retry_times: 最大自动重试次数，当函数发生错误，立即自动重试运行n次，对一些特殊不稳定情况会有效果。
            可以在函数中主动抛出重试的异常ExceptionForRetry，框架也会立即自动重试。
            主动抛出ExceptionForRequeue异常，则当前消息会重返中间件。
-    :param log_level:框架的日志级别。
+    :param log_level:框架的日志级别。logging.DEBUG(10)  logging.DEBUG(10) logging.INFO(20) logging.WARNING(30) logging.ERROR(40) logging.CRITICAL(50)
     :param is_print_detail_exception:是否打印详细的堆栈错误。为0则打印简略的错误占用控制台屏幕行数少。
     :param msg_schedule_time_intercal:消息调度的时间间隔，用于控频的关键。
     :param qps:指定1秒内的函数执行次数，qps会覆盖msg_schedule_time_intercal，以后废弃msg_schedule_time_intercal这个参数。
