@@ -5,6 +5,8 @@
 对比官方线程池，有4个创新功能或改进。
 
 1、主要是不仅能扩大，还可自动缩小(官方内置的ThreadpoolExecutor不具备此功能，此概念是什么意思和目的，可以百度java ThreadpoolExecutor的KeepAliveTime参数的介绍)，
+   例如实例化一个1000线程的线程池，上一分钟疯狂高频率的对线程池submit任务，线程池会扩张到最大线程数量火力全开运行，
+   但之后的七八个小时平均每分钟只submit一两个任务，官方线程池会一直维持在1000线程，而此线程池会自动缩小，靠什么来识别预测啥时机可以自动缩小呢，就是KeepAliveTime。
 
 2、非常节制的开启多线程，例如实例化一个最大100线程数目的pool，每隔2秒submit一个函数任务，而函数每次只需要1秒就能完成，实际上只需要调节增加到1个线程就可以，不需要慢慢增加到100个线程
 官方的线程池不够智能，会一直增加到最大线程数目，此线程池则不会。
@@ -14,6 +16,8 @@
 4、此线程池运行函数出错时候，直接显示线程错误，官方的线程池则不会显示错误，例如函数中写1/0,任然不现实错误。
 
 此实现了submit，还实现future相关的内容，真正的和内置的ThreadpoolExecutor 完全替代。
+
+可以在各种地方加入 time.sleep 来验证 第1条和第2条的自动智能缩放功能。
 """
 import os
 import atexit
@@ -77,18 +81,27 @@ class _WorkItem(LoggerMixin):
         return f'{(self.fn.__name__, self.args, self.kwargs)}'
 
 
+def set_threadpool_executor_shrinkable(min_works=1, keep_alive_time=10):
+    ThreadPoolExecutorShrinkAble.MIN_WORKERS = min_works
+    ThreadPoolExecutorShrinkAble.KEEP_ALIVE_TIME = keep_alive_time
+
+
 class ThreadPoolExecutorShrinkAble(Executor, LoggerMixin, LoggerLevelSetterMixin):
     # 为了和官方自带的THredpoolexecutor保持完全一致的鸭子类，参数设置成死的，不然用户传参了。
-    MIN_WORKERS = 5
-    KEEP_ALIVE_TIME = 60
+    # 建议用猴子补丁修改这两个参数，为了保持入参api和内置的concurrent.futures 相同。
+    # MIN_WORKERS = 5   # 最小值可以设置为0，代表线程池无论多久没有任务最少要保持多少个线程待命。
+    # KEEP_ALIVE_TIME = 60  # 这个参数表名，当前线程从queue.get(block=True, timeout=KEEP_ALIVE_TIME)多久没任务，就线程结束。
 
-    def __init__(self, max_workers=None, thread_name_prefix=''):
+    MIN_WORKERS = 1
+    KEEP_ALIVE_TIME = 10
+
+    def __init__(self, max_workers: int = None, thread_name_prefix=''):
         """
         最好需要兼容官方concurren.futures.ThreadPoolExecutor 和改版的BoundedThreadPoolExecutor，入参名字和个数保持了一致。
         :param max_workers:
         :param thread_name_prefix:
         """
-        self._max_workers = max_workers or 4
+        self._max_workers = max_workers if max_workers is not None else (os.cpu_count() or 1) * 5
         self._thread_name_prefix = thread_name_prefix
         self.work_queue = self._work_queue = queue.Queue(max_workers)
         # self._threads = set()
@@ -97,6 +110,7 @@ class ThreadPoolExecutorShrinkAble(Executor, LoggerMixin, LoggerLevelSetterMixin
         self.threads_free_count = 0
         self._shutdown = False
         self._shutdown_lock = threading.Lock()
+        self.pool_ident = id(self)
 
     def _change_threads_free_count(self, change_num):
         with self._lock_compute_threads_free_count:
@@ -114,7 +128,7 @@ class ThreadPoolExecutorShrinkAble(Executor, LoggerMixin, LoggerLevelSetterMixin
 
     def _adjust_thread_count(self):
         # print(self.threads_free_count, self.MIN_WORKERS, len(self._threads), self._max_workers)
-        if self.threads_free_count < self.MIN_WORKERS and len(self._threads) < self._max_workers:
+        if self.threads_free_count <= self.MIN_WORKERS and len(self._threads) < self._max_workers:
             t = _CustomThread(self).set_log_level(self.logger.level)
             t.daemon = True
             t.start()
@@ -163,8 +177,8 @@ class _CustomThread(threading.Thread, LoggerMixin, LoggerLevelSetterMixin):
                 with self._lock_for_judge_threads_free_count:
                     if self._executorx.threads_free_count > self._executorx.MIN_WORKERS:
                         self._remove_thread(
-                            f'当前线程超过 {self._executorx.KEEP_ALIVE_TIME} 秒没有任务，线程池中不在工作状态中的线程数量是 '
-                            f'{self._executorx.threads_free_count}，超过了指定的数量 {self._executorx.MIN_WORKERS}')
+                            f'{self._executorx.pool_ident} 线程池中的 {self.ident} 线程 超过 {self._executorx.KEEP_ALIVE_TIME} 秒没有任务，线程池中不在工作状态中的线程数量是 '
+                            f'{self._executorx.threads_free_count}，超过了指定的最小核心数量 {self._executorx.MIN_WORKERS}')
                         break  # 退出while 1，即是结束。这里才是决定线程结束销毁，_remove_thread只是个名字而已，不是由那个来销毁线程。
                     else:
                         continue
@@ -186,6 +200,7 @@ logger_show_current_threads_num = LogManager('show_current_threads_num').get_log
 
 
 def show_current_threads_num(sleep_time=600, process_name='', block=False, daemon=True):
+    """另起一个线程每隔多少秒打印有多少线程，这个和可缩小线程池的实现没有关系"""
     process_name = sys.argv[0] if process_name == '' else process_name
 
     def _show_current_threads_num():
@@ -214,7 +229,7 @@ if __name__ == '__main__':
 
 
     def f1(a):
-        time.sleep(2)  # 可修改这个数字测试多线程数量调节功能。
+        time.sleep(0.2)  # 可修改这个数字测试多线程数量调节功能。
         nb_print(f'{a} 。。。。。。。')
         return a * 10
         # raise Exception('抛个错误测试')  # 官方的不会显示函数出错你，你还以为你写的代码没毛病呢。
@@ -223,8 +238,8 @@ if __name__ == '__main__':
     pool = ThreadPoolExecutorShrinkAble(200)
     # pool = ThreadPoolExecutor(200)  # 测试对比官方自带
 
-    for i in range(300):
-        time.sleep(0.5)  # 这里的间隔时间模拟，当任务来临不密集，只需要少量线程就能搞定f1了，因为f1的消耗时间短，
+    for i in range(30):
+        time.sleep(0.05)  # 这里的间隔时间模拟，当任务来临不密集，只需要少量线程就能搞定f1了，因为f1的消耗时间短，
         # 不需要开那么多线程，CustomThreadPoolExecutor比ThreadPoolExecutor 优势之一。
         futurex = pool.submit(f1, i)
         # print(futurex.result())
